@@ -64,50 +64,50 @@ with_mock_HTTP({
 
     test_that("Basic box", {
         expect_POST(crunchBox(ds, filters=NULL),
-            '/api/datasets/1/boxdata/',
+            'api/datasets/1/boxdata/',
             '{"element":"shoji:entity","body":{"filters":[]}}')
     })
     test_that("Basic box with metadata and filters", {
         expect_POST(crunchBox(ds, title="Test box"),
-            '/api/datasets/1/boxdata/',
+            'api/datasets/1/boxdata/',
             '{"element":"shoji:entity","body":{"filters":[',
-            '{"filter":"/api/datasets/1/filters/filter1/"},',
-            '{"filter":"/api/datasets/1/filters/filter2/"}],',
+            '{"filter":"api/datasets/1/filters/filter1/"},',
+            '{"filter":"api/datasets/1/filters/filter2/"}],',
             '"title":"Test box"}}')
     })
     test_that("Select variables in box", {
         expect_POST(crunchBox(ds[2:4], filters=NULL),
-            '/api/datasets/1/boxdata/',
+            'api/datasets/1/boxdata/',
             '{"element":"shoji:entity","body":{"filters":[],',
             '"where":{"function":"select","args":[{"map":{',
             '"66ae9881e3524f7db84970d556c34552":',
-            '{"variable":"/api/datasets/1/variables/gender/"},',
+            '{"variable":"api/datasets/1/variables/gender/"},',
             '"949d2dc7e7a24e6090cc88bb92e1d2fb":',
-            '{"variable":"/api/datasets/1/variables/mymrset/"},',
-            '"text":{"variable":"/api/datasets/1/variables/textVar/"}',
+            '{"variable":"api/datasets/1/variables/mymrset/"},',
+            '"text":{"variable":"api/datasets/1/variables/textVar/"}',
             '}}]}}}')
     })
     test_that("Hidden variables are automatically 'selected' out", {
         expect_POST(crunchBox(ds3),
-            '/api/datasets/3/boxdata/',
+            'api/datasets/3/boxdata/',
             '{"element":"shoji:entity","body":{"filters":[],"where":',
             '{"function":"select","args":[{"map":{',
             '"66ae9881e3524f7db84970d556c34552":',
-            '{"variable":"/api/datasets/3/variables/gender/"},',
+            '{"variable":"api/datasets/3/variables/gender/"},',
             '"d7c21314ca9e453c93069168681a285c":',
-            '{"variable":"/api/datasets/3/variables/starttime/"}}}]}}}')
+            '{"variable":"api/datasets/3/variables/starttime/"}}}]}}}')
     })
     test_that("Select filters in box", {
         expect_POST(crunchBox(ds, filters=filters(ds)[c(2, 1)], title="Test box"),
-            '/api/datasets/1/boxdata/',
+            'api/datasets/1/boxdata/',
             '{"element":"shoji:entity","body":{"filters":[',
-            '{"filter":"/api/datasets/1/filters/filter2/"},',
-            '{"filter":"/api/datasets/1/filters/filter1/"}],',
+            '{"filter":"api/datasets/1/filters/filter2/"},',
+            '{"filter":"api/datasets/1/filters/filter1/"}],',
             '"title":"Test box"}}')
         expect_POST(crunchBox(ds, filters=filters(ds)[2]),
-            '/api/datasets/1/boxdata/',
+            'api/datasets/1/boxdata/',
             '{"element":"shoji:entity","body":{"filters":[',
-            '{"filter":"/api/datasets/1/filters/filter2/"}]}}')
+            '{"filter":"api/datasets/1/filters/filter2/"}]}}')
     })
     test_that("Input validation", {
         expect_error(crunchBox(), "'dataset' must be a CrunchDataset")
