@@ -44,8 +44,8 @@ test_that("ShojiCatalog", {
 })
 
 with_mock_HTTP({
-    full.urls <- DatasetCatalog(crGET("/api/datasets/"))
-    rel.urls <- DatasetCatalog(crGET("/api/datasets/", query=list(relative="on")))
+    full.urls <- DatasetCatalog(crGET("api/datasets/"))
+    rel.urls <- DatasetCatalog(crGET("api/datasets/", query=list(relative="on")))
     test_that("urls() method returns absolute URLs", {
         expect_identical(urls(full.urls), urls(rel.urls))
     })
@@ -53,7 +53,7 @@ with_mock_HTTP({
     test_that("shojiURL", {
         ds <- loadDataset("test ds")
         expect_identical(shojiURL(ds, "catalogs", "variables"),
-            "/api/datasets/1/variables/")
+            "api/datasets/1/variables/")
         expect_error(shojiURL(ds, "catalogs", "NOTACATALOG"),
             paste0("No URL ", dQuote("NOTACATALOG"), " in collection ",
             dQuote("catalogs")))
@@ -61,14 +61,13 @@ with_mock_HTTP({
 })
 
 with_test_authentication({
-    with(test.dataset(df), {
-        test_that("refresh", {
-            expect_identical(ds, refresh(ds))
-            ds2 <- ds
-            ds2@body$name <- "something else"
-            expect_false(identical(ds2, ds))
-            expect_false(identical(ds2, refresh(ds2)))
-            expect_identical(refresh(ds2), ds)
-        })
+    ds <- newDataset(df[1:2, 1:2])
+    test_that("refresh", {
+        expect_identical(ds, refresh(ds))
+        ds2 <- ds
+        ds2@body$name <- "something else"
+        expect_false(identical(ds2, ds))
+        expect_false(identical(ds2, refresh(ds2)))
+        expect_identical(refresh(ds2), ds)
     })
 })
